==> ejc-settlementmanage-impl-3.0.0-20221202.092227-124-sources.jar: com/ejianc/business/settlementmanage/bean/EventListdetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 影响总包结算的关键事项清单子表-影响总包结算原因及处理人
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_event_listdetail")
public class EventListdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="settlement_reason")
    private java.lang.String settlementReason; // 影响总包结算的原因
    @TableField(value="measures")
    private java.lang.String measures; // 措施
    @TableField(value="responsibilities")
    private java.lang.String responsibilities; // 工作组
    @TableField(value="regional_company")
    private java.lang.String regionalCompany; // 区域公司
    @TableField(value="branch_office")
    private java.lang.String branchOffice; // 分公司
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目
    @TableField(value="time_point")
    private java.util.Date timePoint; // 时间节点
    @TableField(value="development")
    private java.lang.String development; // 进展情况(按周汇报)
    private java.lang.String matterType; // 事项类型
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 影响总包结算的原因
     */
    public java.lang.String getSettlementReason() {
        return settlementReason;
    }

    /**
     * 影响总包结算的原因
     */
    public void setSettlementReason(java.lang.String settlementReason) {
        this.settlementReason = settlementReason;
    }
    /**
     * 措施
     */
    public java.lang.String getMeasures() {
        return measures;
    }

    /**
     * 措施
     */
    public void setMeasures(java.lang.String measures) {
        this.measures = measures;
    }
    /**
     * 工作组
     */
    public java.lang.String getResponsibilities() {
        return responsibilities;
    }

    /**
     * 工作组
     */
    public void setResponsibilities(java.lang.String responsibilities) {
        this.responsibilities = responsibilities;
    }
    /**
     * 区域公司
     */
    public java.lang.String getRegionalCompany() {
        return regionalCompany;
    }

    /**
     * 区域公司
     */
    public void setRegionalCompany(java.lang.String regionalCompany) {
        this.regionalCompany = regionalCompany;
    }
    /**
     * 分公司
     */
    public java.lang.String getBranchOffice() {
        return branchOffice;
    }

    /**
     * 分公司
     */
    public void setBranchOffice(java.lang.String branchOffice) {
        this.branchOffice = branchOffice;
    }
    /**
     * 项目
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 时间节点
     */
    public java.util.Date getTimePoint() {
        return timePoint;
    }

    /**
     * 时间节点
     */
    public void setTimePoint(java.util.Date timePoint) {
        this.timePoint = timePoint;
    }
    /**
     * 进展情况(按周汇报)
     */
    public java.lang.String getDevelopment() {
        return development;
    }

    /**
     * 进展情况(按周汇报)
     */
    public void setDevelopment(java.lang.String development) {
        this.development = development;
    }

    public String getMatterType() {
        return matterType;
    }

    public void setMatterType(String matterType) {
        this.matterType = matterType;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230323.014022-192-sources.jar: com/ejianc/business/settlementmanage/bean/EventListdetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 影响总包结算的关键事项清单子表-影响总包结算原因及处理人
 *
 * @author generator
 *
 */
 @TableName("ejc_settlementmanage_event_listdetail")
public class EventListdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="settlement_reason")
    private java.lang.String settlementReason; // 影响总包结算的原因
    @TableField(value="measures")
    private java.lang.String measures; // 措施
    @TableField(value="responsibilities")
    private java.lang.String responsibilities; // 工作组
    @TableField(value="regional_company")
    private java.lang.String regionalCompany; // 区域公司
    @TableField(value="branch_office")
    private java.lang.String branchOffice; // 分公司
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目
    @TableField(value="time_point")
    private java.util.Date timePoint; // 时间节点
    @TableField(value="development")
    private java.lang.String development; // 进展情况(按周汇报)
    private java.lang.String matterType; // 事项类型
    @TableField(value="plan_accomplish_time")
    private java.util.Date planAccomplishTime; // 计划完成时间
    @TableField(value="reality_accomplish_time")
    private java.util.Date realityAccomplishTime; // 实际完成时间
    @TableField(value="incomplete_condition_analyse")
    private String incompleteConditionAnalyse; // 未完成情况分析
    @TableField(value="is_flag")
    private Integer isFlag; // 是否能删除

    public Date getPlanAccomplishTime() {
        return planAccomplishTime;
    }

    public void setPlanAccomplishTime(Date planAccomplishTime) {
        this.planAccomplishTime = planAccomplishTime;
    }

    public Date getRealityAccomplishTime() {
        return realityAccomplishTime;
    }

    public void setRealityAccomplishTime(Date realityAccomplishTime) {
        this.realityAccomplishTime = realityAccomplishTime;
    }

    public String getIncompleteConditionAnalyse() {
        return incompleteConditionAnalyse;
    }

    public void setIncompleteConditionAnalyse(String incompleteConditionAnalyse) {
        this.incompleteConditionAnalyse = incompleteConditionAnalyse;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 影响总包结算的原因
     */
    public java.lang.String getSettlementReason() {
        return settlementReason;
    }

    /**
     * 影响总包结算的原因
     */
    public void setSettlementReason(java.lang.String settlementReason) {
        this.settlementReason = settlementReason;
    }
    /**
     * 措施
     */
    public java.lang.String getMeasures() {
        return measures;
    }

    /**
     * 措施
     */
    public void setMeasures(java.lang.String measures) {
        this.measures = measures;
    }
    /**
     * 工作组
     */
    public java.lang.String getResponsibilities() {
        return responsibilities;
    }

    /**
     * 工作组
     */
    public void setResponsibilities(java.lang.String responsibilities) {
        this.responsibilities = responsibilities;
    }
    /**
     * 区域公司
     */
    public java.lang.String getRegionalCompany() {
        return regionalCompany;
    }

    /**
     * 区域公司
     */
    public void setRegionalCompany(java.lang.String regionalCompany) {
        this.regionalCompany = regionalCompany;
    }
    /**
     * 分公司
     */
    public java.lang.String getBranchOffice() {
        return branchOffice;
    }

    /**
     * 分公司
     */
    public void setBranchOffice(java.lang.String branchOffice) {
        this.branchOffice = branchOffice;
    }
    /**
     * 项目
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 时间节点
     */
    public java.util.Date getTimePoint() {
        return timePoint;
    }

    /**
     * 时间节点
     */
    public void setTimePoint(java.util.Date timePoint) {
        this.timePoint = timePoint;
    }
    /**
     * 进展情况(按周汇报)
     */
    public java.lang.String getDevelopment() {
        return development;
    }

    /**
     * 进展情况(按周汇报)
     */
    public void setDevelopment(java.lang.String development) {
        this.development = development;
    }

    public String getMatterType() {
        return matterType;
    }

    public void setMatterType(String matterType) {
        this.matterType = matterType;
    }

    public Integer getIsFlag() {
        return isFlag;
    }

    public void setIsFlag(Integer isFlag) {
        this.isFlag = isFlag;
    }
}
